@@ -101,26 +101,59 @@ class VerifyEmailMixin(BasicUserFieldsMixin):
 
     objects = VerifyEmailManager()
 
+    EMAIL_SUBJECT = '{domain} account validate'
+    TEXT_EMAIL_TEMPLATE = 'user_management/account_validation_email.txt'
+    HTML_EMAIL_TEMPLATE = 'user_management/account_validation_email.html'
+
     class Meta:
         abstract = True
 
-    def send_validation_email(self):
-        if not self.email_verification_required:
-            raise ValueError(_('Cannot validate already active user.'))
-
-        site = Site.objects.get_current()
-        context = {
+    def email_context(self, site):
+        return {
             'uid': urlsafe_base64_encode(force_bytes(self.pk)),
             'token': default_token_generator.make_token(self),
             'site': site,
         }
 
-        send(
-            to=[self.email],
-            template_name='user_management/account_validation_email.html',
-            subject=_('{domain} account validate').format(domain=site.domain),
-            context=context,
-        )
+    def email_kwargs(self, context, domain):
+        """Prepare the kwargs to be passed to incuna_mail.send"""
+        return {
+            'to': [self.email],
+            'template_name': self.TEXT_EMAIL_TEMPLATE,
+            'html_template_name': self.HTML_EMAIL_TEMPLATE,
+            'subject': self.get_email_subject(domain),
+            'context': context,
+        }
+
+    def get_email_subject(self, domain):
+        return _(self.EMAIL_SUBJECT).format(domain=domain)
+
+    def send_validation_email(self):
+        """
+        Send a validation email to the user's email address.
+
+        The email subject can be customised by overriding
+        VerifyEmailMixin.EMAIL_SUBJECT or VerifyEmailMixin.get_email_subject.
+        To include your site's domain in the subject, include {domain} in
+        VerifyEmailMixin.EMAIL_SUBJECT.
+
+        By default send_validation_email sends a multipart email using
+        VerifyEmailMixin.TEXT_EMAIL_TEMPLATE and
+        VerifyEmailMixin.HTML_EMAIL_TEMPLATE. To send a text-only email
+        set VerifyEmailMixin.HTML_EMAIL_TEMPLATE to None.
+
+        You can also customise the context available in the email templates
+        by extending VerifyEmailMixin.email_context.
+
+        If you want more control over the sending of the email you can
+        extend VerifyEmailMixin.email_kwargs.
+        """
+        if not self.email_verification_required:
+            raise ValueError(_('Cannot validate already active user.'))
+
+        site = Site.objects.get_current()
+        context = self.email_context(site)
+        send(**self.email_kwargs(context, site.domain))
 
     @classmethod
     def check(cls, **kwargs):
@@ -142,6 +175,7 @@ class VerifyEmailMixin(BasicUserFieldsMixin):
             ),
         ]
 
+
 class AvatarMixin(models.Model):
     avatar = models.ImageField(upload_to='user_avatar', null=True, blank=True)
 
